@@ -37,7 +37,7 @@ use HTML::Table::FromDatabase;
 use CGI::FormBuilder;
 use HTML::Entities;
 
-our $VERSION = '0.93';
+our $VERSION = '0.94';
 
 =encoding utf8
 
@@ -61,6 +61,11 @@ easy to set up and use.
 
 =head1 SYNOPSIS
 
+The following assumes that you already have a working L<Dancer> app and have
+put your database connection details in your C<config.yml> to be read by
+L<Dancer::Plugin::Database>, which this plugin uses in order to obtain a database
+connection.
+
     # In your Dancer app,
     use Dancer::Plugin::SimpleCRUD;
 
@@ -1330,7 +1335,7 @@ sub _ensure_auth {
     } else {
         for my $keyword (qw(require_role require_any_role require_all_roles)) {
             if (my $val = $auth_settings->{$keyword}) {
-                return $handler = Dancer::Plugin::Auth::Extensible->$keyword(
+                return $handler = Dancer::Plugin::Auth::Extensible->can($keyword)->(
                     $val, $handler
                 );
             }
